@@ -75,10 +75,48 @@ def test_regionprops(make_napari_viewer):
     from napari_skimage_regionprops import add_table
     add_table(labels_layer, viewer)
 
+    # Append table
+    fake_measurement = area_measurements * 2
+    fake_area = {'Double area': fake_measurement}
+    table_widget.append_content(fake_area)
+    assert 'Double area' in table_widget.get_content().keys()
+
     # empty table
     table_widget.set_content(None)
     table_widget.update_content()
 
+# add your tests here...
+def test_append_table_by_merging(make_napari_viewer):
+
+    viewer = make_napari_viewer()
+
+    import numpy as np
+
+    image = np.asarray([
+        [0, 0],
+        [0, 1],
+    ])
+
+    labels_layer = viewer.add_labels(image)
+
+    table1 = {
+        "A":[1,2,4],
+        "B":[1,2,4]
+    }
+    table2 = {
+        "B":[1,2,4],
+        "C":[1,2,4]
+    }
+    labels_layer.properties = table1
+
+    # Append table
+    from napari_skimage_regionprops import add_table
+    table_widget = add_table(labels_layer, viewer)
+    table_widget.append_content(table2)
+    assert 'A' in table_widget.get_content().keys()
+    assert 'B' in table_widget.get_content().keys()
+    assert 'C' in table_widget.get_content().keys()
+
 def test_regionprops_without_moments(make_napari_viewer):
 
     viewer = make_napari_viewer()
@@ -246,12 +284,22 @@ def test_4d_3d(make_napari_viewer):
 
     # test duplicating the current frame
     from napari_skimage_regionprops._utilities import duplicate_current_frame
-    new_layer = duplicate_current_frame(image, viewer)
+    new_layer = duplicate_current_frame(image_layer, viewer)
 
     assert len(new_layer.data.shape) == 3
     assert np.array_equal(new_layer.data.shape, [3, 7, 7])
 
 
+    # test duplicating the current frame
+    from napari_skimage_regionprops._utilities import duplicate_current_frame
+    new_layer = duplicate_current_frame(labels_layer, viewer)
+    print("LL", labels_layer.data.shape)
+    print("NL", new_layer.data.shape)
+    assert len(new_layer.data.shape) == 2
+    assert np.array_equal(new_layer.data.shape, [7, 7])
+
+
+
 def test_napari_api():
     from napari_skimage_regionprops import napari_experimental_provide_function
     napari_experimental_provide_function()
@@ -259,4 +307,3 @@ def test_napari_api():
 def test_napari_api2():
     from napari_skimage_regionprops._utilities import napari_experimental_provide_function
     napari_experimental_provide_function()
-
